import {Injectable} from '@angular/core';
import {ApiService} from "../../shared/service/api.service";
import {AccountModel, Permission} from "../../shared/model/account.model";
import {Observable} from "rxjs";

@Injectable({
  providedIn: 'root'
})
export class UserService {
  constructor(
    private api: ApiService
  ) {
  }

  get all(): Observable<AccountModel[]> {
    return this.api.get<AccountModel[]>('/user')
  }

  getById(id: number): Observable<AccountModel> {
    return this.api.get<AccountModel>(`/user/${id}`)
  }

  save(id: number, firstName: string, lastName: string, password: string, group: number, permissions: Permission[]): Observable<AccountModel> {
    const user = {id, firstName, lastName, password, groupId: group >= 0 ? group : null, permissions}
    return this.api.post<AccountModel>('/user', user)
  }

  update(id: number, firstName: string, lastName: string, group: number, permissions: Permission[]): Observable<void> {
    const user = {id, firstName, lastName, groupId: group >= 0 ? group : null, permissions}
    return this.api.put<void>('/user', user)
  }

  updatePassword(id: number, password: string): Observable<void> {
    return this.api.put<void>(`/user/${id}/password`, password, true, {contentType: 'text/plain'})
  }

  delete(id: number): Observable<void> {
    return this.api.delete<void>(`/user/${id}`)
  }
}
